summaryrefslogtreecommitdiffhomepage
path: root/dev/BuildKit/JSONManifestBuilder.h
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal@nekernel.org>2025-07-24 09:15:17 +0100
committerAmlal El Mahrouss <amlal@nekernel.org>2025-07-24 09:15:17 +0100
commita3ea256d00e5aac45574c7c8b076b60630f73a95 (patch)
treed639c686922140ee0465b27964ce4d2b854b68b7 /dev/BuildKit/JSONManifestBuilder.h
parentbb11d32131e786b40550375005b12bcb31cf25d7 (diff)
feat! refactor! Breaking changes of the NeBuild system.
Working on a TOML backend, refactored source code namespace. And add 'toml++' vendor library. See commit details. Signed-off-by: Amlal El Mahrouss <amlal@nekernel.org>
Diffstat (limited to 'dev/BuildKit/JSONManifestBuilder.h')
-rw-r--r--dev/BuildKit/JSONManifestBuilder.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/dev/BuildKit/JSONManifestBuilder.h b/dev/BuildKit/JSONManifestBuilder.h
index f7c769d..ba34a69 100644
--- a/dev/BuildKit/JSONManifestBuilder.h
+++ b/dev/BuildKit/JSONManifestBuilder.h
@@ -6,12 +6,12 @@
#pragma once
#include <BuildKit/IManifestBuilder.h>
-#include <json.h>
+#include <json/json.h>
/// @file JSONManifestBuilder.h
/// @brief JSON manifest builder header file.
-namespace BTB {
+namespace NeBuild {
/// @brief JSON builder
class JSONManifestBuilder final NEBUILD_MANIFEST_BUILDER {
public:
@@ -30,4 +30,4 @@ class JSONManifestBuilder final NEBUILD_MANIFEST_BUILDER {
bool buildTarget(int arg_sz, const char* arg_val, const bool dry_run = false) override;
const char* buildSystem() override;
};
-} // namespace BTB \ No newline at end of file
+} // namespace NeBuild \ No newline at end of file